@@ -11,11 +11,11 @@
 #' The response variable and covariates are specified here.
 #' @param data \emph{optional} data frame containing the response variable and the covariates. If not found in \code{data},
 #' the variables are taken from \code{environment(formula)}. No \code{NA}s are allowed in the response variable or covariates.
-#' @param a positive real number controlling the shrinkage prior for the covariance structure. The default is 0.5.
+#' @param a positive real number controlling the behavior at the origin of the shrinkage prior for the covariance structure. The default is 0.5.
 #' @param c positive real number controlling the tail behavior of the shrinkage prior for the covariance structure. The default is 0.5.
-#' @param formula_mean \emph{optional} formula for the mean equation. If provided, the response variable and covariates for the mean structure
-#' are specified separately from the covariance structure.
-#' @param a_mean positive real number controlling the shrinkage prior for the mean structure. The default is 0.5.
+#' @param formula_mean \emph{optional} formula for the linear mean equation. If provided, the covariates for the mean structure
+#' are specified separately from the covariance structure. A response variable is not required in this formula.
+#' @param a_mean positive real number controlling the behavior at the origin of the shrinkage for the mean structure. The default is 0.5.
 #' @param c_mean positive real number controlling the tail behavior of the shrinkage prior for the mean structure. The default is 0.5.
 #' @param sigma2_rate positive real number controlling the prior rate parameter for the residual variance. The default is 10.
 #' @param kernel_func function specifying the covariance kernel. The default is \code{\link{kernel_se}}, a squared exponential kernel.
@@ -172,6 +172,11 @@
 #'         col = adjustcolor("skyblue", alpha.f = 0.5), border = NA)
 #'   points(x[,1], y)
 #'   curve(sin(2 * pi * x), add = TRUE, col = "forestgreen", lwd = 2, lty = 2)
+#'
+#'
+#'
+#'   # Add mean equation
+#'   res2 <- shrinkGPR(y ~ x1 + x2, formula_mean = ~ x1, data = data)
 #'   }
 #' }
 #' @export
@@ -428,14 +433,15 @@ shrinkGPR <- function(formula,
         log_det_J <- zk_log_det_J$log_det_J
 
         # Calculate loss, i.e. ELBO
-        loss <- -model$elbo(zk_pos, log_det_J)
+        # suppressWarnings because torchscript does not yet support torch.linalg.cholesky
+        loss <- suppressMessages(-model$elbo(zk_pos, log_det_J))
         loss_stor[i] <- loss$item()
 
         # Zero gradients
         optimizer$zero_grad()
 
         # Compute gradients, i.e. backprop
-        loss$backward(retain_graph = TRUE)
+        loss$backward(retain_graph = FALSE)
 
         # Update parameters
         optimizer$step()
@@ -489,7 +495,7 @@ shrinkGPR <- function(formula,
           pb$tick(tokens = list(message = curr_message))
         }
       }
-    }, interrupt = function(ex) {
+  }, interrupt = function(ex) {
       stop_reason <<- "interrupted"
       if (display_progress) {
         pb$terminate()
